Learn R Programming

DSMolgenisArmadillo (version 3.0.2)

ArmadilloDriver-class: Class ArmadilloDriver with constructor armadillo

Description

An Armadillo DataSHIELD Service Driver implementing the DataSHIELD Interface (DSI) DSDriver-class. This class should always be initialized with the armadillo function. It returns a singleton that allows you to connect to Armadillo

Arguments