DSMolgenisArmadillo-defunct: Defunct functions in package 'DSMolgenisArmadillo'.

armadillo.get_tokenR Documentation

Defunct functions in package DSMolgenisArmadillo.

Description

The functions listed below are defunct and no longer available. When possible, alternative functions with similar functionality are mentioned. Help pages for deprecated functions are available at help("<function>-defunct").

Usage

armadillo.get_token(server)

armadillo.get_token

[Defunct]

For armadillo.get_token, use armadillo.get_credentials() instead.


DSMolgenisArmadillo documentation built on March 26, 2026, 5:07 p.m.