Learn R Programming

DSMolgenisArmadillo (version 3.0.2)

DSMolgenisArmadillo-package: DSMolgenisArmadillo: 'DataSHIELD' Client for 'MOLGENIS Armadillo'

Description

'DataSHIELD' is an infrastructure and series of R packages that enables the remote and 'non-disclosive' analysis of sensitive research data. This package is the 'DataSHIELD' interface implementation to analyze data shared on a 'MOLGENIS Armadillo' server. 'MOLGENIS Armadillo' is a light-weight 'DataSHIELD' server using a file store and an 'RServe' server.

Arguments

Author

Maintainer: Mariska Slofstra m.k.slofstra@umcg.nl (ORCID)

Authors:

Other contributors:

See Also