Learn R Programming

DSMolgenisArmadillo (version 3.0.2)

dsAssignResource,ArmadilloConnection-method: Assign a resource

Description

Assign a resource in the DataSHIELD R session.

Usage

# S4 method for ArmadilloConnection
dsAssignResource(conn, symbol, resource, async = TRUE)

Value

A ArmadilloResult-class object.

Arguments

conn

An object that inherits from DSConnection-class.

symbol

Name of the R symbol.

resource

Fully qualified name of a resource reference in the data repository.

async

Whether the result of the call should be retrieved asynchronously.