Learn R Programming

DSMolgenisArmadillo (version 3.0.2)

dsGetInfo,ArmadilloResult-method: Get result info

Description

Await completion and get the information about a command (if still available).

Usage

# S4 method for ArmadilloResult
dsGetInfo(dsObj, ...)

Value

The result information. This should include the R expression being executed (`expression`) and if the query is complete (`{ "status" = "COMPLETED" }`).

Arguments

dsObj

ArmadilloResult-class class object

...

Unused, needed for compatibility with generic.