dsGetInfo-ArmadilloResult-method: Get result info

dsGetInfo,ArmadilloResult-methodR Documentation

Get result info

Description

Await completion and get the information about a command (if still available).

Usage

## S4 method for signature 'ArmadilloResult'
dsGetInfo(dsObj, ...)

Arguments

dsObj

ArmadilloResult-class class object

...

Unused, needed for compatibility with generic.

Value

The result information. This should include the R expression being executed (expression) and if the query is complete (⁠\{ "status" = "COMPLETED" \}⁠).


DSMolgenisArmadillo documentation built on March 26, 2026, 5:07 p.m.