dsHasTable,ArmadilloConnection-method: Verify table exist and can be accessible for performing DataSHIELD
operations.
Description
Verify table exist and can be accessible for performing DataSHIELD
operations.
Usage
# S4 method for ArmadilloConnection
dsHasTable(conn, table)
Value
TRUE if table exists.
Arguments
- conn
ArmadilloConnection-class class object.
- table
The identifier of the table