Learn R Programming

DSMolgenisArmadillo (version 3.0.2)

dsKeepAlive,ArmadilloConnection-method: Keep a connection alive

Description

As the DataSHIELD sessions are working in parallel, this function helps at keeping idle connections alive while others are working. Any communication failure must be silently processed.

Usage

# S4 method for ArmadilloConnection
dsKeepAlive(conn)

Value

NULL, invisibly

Arguments

conn

ArmadilloConnection-class class object